# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [2.2.2] - 2025-08-29

### 🔧 Maintenance

- change emoji to code ([5954188])


## [2.2.1] - 2025-08-29

### 🐛 Fixed

- some fixes ([e8a7c82])


## [2.2.0] - 2025-08-29

### ✨ Added

- **workflow**: some updates ([1e2073f])
- some updates ([f45fd74])
- some updates ([f14189a])

### ♻️ Changed

- **ux**: sanitizing and adapting ([a9ca921])

### 🐛 Fixed

- some updates ([ee10aff])
- some updates ([d8df0e5])
- some updates ([58ecd6c])
- fix changelog ([4eba6ef])
- remove ccg command in verify build step ([5ccecc3])
- add get current branch step ([38ba2b3])
- **release**: fix git push origin error ([55c8b7f])

### 🔧 Maintenance

- some updates ([816c778])

